<?php
/**
 * Last change:
 * $Revision: 1.15 $
 * $Date: 2008/05/19 08:00:13 $
 * $Author: liviu $
 * $Id: calendar.php,v 1.15 2008/05/19 08:00:13 liviu Exp $
 */

class Calendar {

	// Engine settings
	public	$firstDayOfWeek	=	'mon';		// can be ONLY "mon" (Monday) OR "sun" (Sunday)
	public	$year			=	'2008';		// format: "yyyy"	(eg: 2008)
	public	$month			=	'04';		// format: "mm"		(eg: 12)
	public	$day			=	'02';		// format: "dd"		(eg: 31)
	
	// Private engine settings
	private	$monthDaysNo			=	null;
	private $lastDayOfFirstLine		=	null;
	private $lastDayOfMiddleLine	=	null;
	
	// Style settings
	public	$dayLenght				=	'short';		// can be: full, short OR first
	public	$calendarWidth			=	'150px';
	public	$calendarHeight			=	'250px';
	
	public	$outsideBorderSize		=	'1px';			// 1px
	public	$outsideBorderType		=	'solid';		// outset, groove, dotted, dashed, etc
	public	$outsideBorderColor		=	'#D5D6B4';		// #FFFF00

	public	$insideBorderSize		=	'1px';
	public	$insideBorderType		=	'dashed';		// outset, groove, dotted, dashed, etc
	public	$insideBorderColor		=	'#D5D6B4';		// #00FFFF
	
	public	$bgColor				=	'#FFFFFF';		// #19FFEA
	public	$emptyCell				=	'&nbsp;';
	
	public	$workdaysColor			=	'#000000';
	public	$saturdayColor			=	'#B53237';
	public	$sundayColor			=	'#B53237';
	
	public	$selectedDayColor		=	'#6B7533';
	public	$selectedDayBgColor		=	'#FABA6B';



	/**
	 * Get name of the first day by year and month
	 * 
	 * @param	$date : date (yy-mm)
	 * @param	$returnType	: can be (1) "s" to return string or (2) "i" to return integer
	 * @return	string
	 * 
	 * @author	Liviu
	 * @since 	Apr 2, 2008
	 */
	public function getfirstDayOfMonthByYearAndMonth($date, $returnType = 's') {

		list($year, $month) = explode("-", $date);
		$lastDay = mktime(0, 0, 0, $month, 1, $year);
		
		// If return type is "i" (integer eg: 1, 2, 3... 7)
		if($returnType == 'i') {
			
			// If first day of week is Monday
			if(FIRST_DAY_OF_WEEK == 'mon') {
				return $this->translateDayNameInDayNumber(date('D', $lastDay));
			
			// If first day of week is Sunday
			} elseif(FIRST_DAY_OF_WEEK == 'sun') {
				return $this->translateDayNameInDayNumber(date('D', $lastDay))+1;
			}
			
		// Else if return type is "s" (string, eg: Mon, Tue, ... Sun) 
		} elseif($returnType == 's') {
			return date('D', $lastDay);
		}
	}



	/**
	 * Get numbers of day by year and month
	 * 
	 * @param	date (yy-mm)
	 * @return	string
	 * 
	 * @author	Liviu
	 * @since 	Apr 2, 2008
	 */
	public function getNoOfMonthDaysByYearAndMonth($date) {

		list($year, $month) = explode('-', $date);
		$dayNo = mktime(0, 0, 0, $month+1, 0, $year);

		return date('d', $dayNo);
	}

	
	
	/**
	 * Translate day name in day number (eg: mon => 1)
	 * 
	 * @access	private
	 * @param	string (day name)
	 * @return	integer
	 * 
	 * @author	Liviu
	 * @since 	Apr 2, 2008
	 */
	private function translateDayNameInDayNumber($dayName) {
		
		$dayName = strtolower($dayName);
		
		// General translate (when first day of week is Mon)
		switch($dayName) {

			case 'mon':
				$dayNumber = 1;
				break;
			
			case 'tue':
				$dayNumber = 2;
				break;
				
			case 'wed':
				$dayNumber = 3;
				break;
				
			case 'thu':
				$dayNumber = 4;
				break;
				
			case 'fri':
				$dayNumber = 5;
				break;
				
			case 'sat':
				$dayNumber = 6;
				break;
				
			case 'sun':
				$dayNumber = 7;
				break;
		}
		
		return $dayNumber;
	}
	
	

	/**
	 * Show days of week
	 * 
	 * @param	string
	 * @return	array()
	 * 
	 * @author	Liviu
	 * @since 	Apr 2, 2008
	 */
	public function daysOfWeek($firstDayOfWeek = FIRST_DAY_OF_WEEK) {
		if($firstDayOfWeek == 'mon') {
			$daysOfWeek	=	array	(
										array	(
													'full'	=>	'Monday',
													'short'	=>	'Mon',
													'first'	=>	'M'
												),
										
										array	(
													'full'	=>	'Tuesday',
													'short'	=>	'Thu',
													'first'	=>	'F'
												),
												
										array	(
													'full'	=>	'Wednesday',
													'short'	=>	'Wed',
													'first'	=>	'W'
												),
												
										array	(
													'full'	=>	'Thursday',
													'short'	=>	'Thu',
													'first'	=>	'T'
												),
												
										array	(
													'full'	=>	'Friday',
													'short'	=>	'Fri',
													'first'	=>	'F'
												),
												
										array	(
													'full'	=>	'Saturday',
													'short'	=>	'Sat',
													'first'	=>	'S'
												),
												
										array	(
													'full'	=>	'Sunday',
													'short'	=>	'Sun',
													'first'	=>	'S'
												)
									);
									
		} elseif($firstDayOfWeek == 'sun') {
			$daysOfWeek	=	array	(
										array	(
													'full'	=>	'Sunday',
													'short'	=>	'Sun',
													'first'	=>	'S'
												),
														
										array	(
													'full'	=>	'Monday',
													'short'	=>	'Mon',
													'first'	=>	'M'
												),
										
										array	(
													'full'	=>	'Tuesday',
													'short'	=>	'Thu',
													'first'	=>	'F'
												),
												
										array	(
													'full'	=>	'Wednesday',
													'short'	=>	'Wed',
													'first'	=>	'W'
												),
												
										array	(
													'full'	=>	'Thursday',
													'short'	=>	'Thu',
													'first'	=>	'T'
												),
												
										array	(
													'full'	=>	'Friday',
													'short'	=>	'Fri',
													'first'	=>	'F'
												),
												
										array	(
													'full'	=>	'Saturday',
													'short'	=>	'Sat',
													'first'	=>	'S'
												)
									);
		}
		
		return $daysOfWeek;
	}
	
	
	
	/**
	 * Convert integer month to string
	 * 
	 * @param	integer
	 * @return 	string
	 * 
	 * @author	Liviu
	 * @since 	Apr 2, 2008
	 */
	public function convertIntMonthToString($month) {
		
		switch($month) {
			case '1':
				$monthName = 'January';
				break;
				
			case '2':
				$monthName = 'February';
				break;
				
			case '3':
				$monthName = 'March';
				break;
				
			case '4':
				$monthName = 'April';
				break;
				
			case '5':
				$monthName = 'May';
				break;
				
			case '6':
				$monthName = 'June';
				break;
				
			case '7':
				$monthName = 'July';
				break;
				
			case '8':
				$monthName = 'August';
				break;
				
			case '9':
				$monthName = 'September';
				break;
				
			case '10':
				$monthName = 'Octomber';
				break;
				
			case '11':
				$monthName = 'November';
				break;
			
			case '12':
				$monthName = 'December';
				break; 
		}
		
		return $monthName;
	}
	
	
	
	public function convertIntDayToString($day) {
		
		switch($day) {
			case 1:
				$dayName = 'Mon';
				break;
				
			case 2:
				$dayName = 'Tue';
				break;
				
			case 3:
				$dayName = 'Wed';
				break;
				
			case 4:
				$dayName = 'Thu';
				break;
				
			case 5:
				$dayName = 'Fri';
				break;
				
			case 6:
				$dayName = 'Sat';
				break;
				
			case 7:
				$dayName = 'Sun';
				break;	
		}
		
		return $dayName;
		
	}
	
	
	
	private function selectDayInCalendar($day) {
		if ($_SESSION['calendarDay'] == $day) {
			return 'class="calendar_activeday"';
		}
	}
	
	
	
	private function makeDayHiperlink($day) {
		return "<a href=\"". SERVER_ROOT ."/common/controller.php?action=doChangeDailyCalendarExe&year=". $this->year ."&month=". $this->month ."&day={$day}\" style=\"display:block\">";
	}
	
	
	
	/**
	 * first line of the calendar (first line with days numbers)
	 * 
	 * @author	Liviu
	 * @since 	Apr 2, 2008
	 */
	private function getUpperDays() {

		// Set date format (YYYY-MM)
		$date		=	$this->year .'-'.$this->month;
		
		// Get first day of date (integer day)
		$firstDayInt =	$this->getfirstDayOfMonthByYearAndMonth($date, 'i');
		
		// Get number of days for date
		$daysNo				=	$this->getNoOfMonthDaysByYearAndMonth($date);
		$this->monthDaysNo	=	$daysNo;
		$day				=	0;
		
		echo '<tr>';
		for($i = 1; $i <= 7; $i++) {
			
			// If first day of month equal with $i
			if($firstDayInt <= $i) {
				$day++;
				echo '<td '. $this->selectDayInCalendar($day) .'>'. $this->makeDayHiperlink($day) ."{$day}</a></td>";
				
			} else {
				echo "<td>{$this->emptyCell}</td>";
			}
		}
		echo '</tr>';
		
		$this->lastDayOffirstLine = $day;
	}
	
	
	
	/**
	 * Middle lines of the calendar (lines with 7 full days)
	 * 
	 * @author	Liviu
	 * @since 	Apr 2, 2008
	 */
	private function getMiddleDays() {

		// [1] Calculate last day of middle lines days (every line should be full data)
		for($i = $this->lastDayOffirstLine+1; $i <= $this->monthDaysNo; $i = $i+7) {
			if($i + 6 < $this->monthDaysNo) {
				if($i + 6 > $this->monthDaysNo - 6) {
					$middleDaysLastDay = $i+6;
				}
			}
		}
		
		if(!is_numeric($middleDaysLastDay)) {
			$middleDaysLastDay = $this->monthDaysNo;
		}
		
		
		$this->lastDayOfMiddleLine = $middleDaysLastDay; 
		
		echo '<tr>';
		$k = 0;
		for($i = $this->lastDayOffirstLine+1; $i <= $middleDaysLastDay; $i++) {
			$k++;
			echo '<td '. $this->selectDayInCalendar($i) .'>'. $this->makeDayHiperlink($i) ."{$i}</a></td>";
			
			if($k % 7 == 0) {
				echo '</tr><tr>';
			}
		}
		
	}
	
	
	
	/**
	 * Lower line of calendar (lines with last 1-6 days)
	 * 
	 * @access	private
	 * 
	 * @author	Liviu
	 * @since 	Apr 2, 2008
	 */
	private function getLowerDays() {
		if($this->lastDayOfMiddleLine < $this->monthDaysNo) {
			
			echo '<tr>';
			for($i = $this->lastDayOfMiddleLine+1; $i <= $this->lastDayOfMiddleLine+7; $i++) {
				if($i <= $this->monthDaysNo) {
					echo '<td '. $this->selectDayInCalendar($i) .'>'. $this->makeDayHiperlink($i) ."{$i}</a></td>";
				} else {
					echo "<td>{$this->emptyCell}</td>";
				}
			}
			echo '</tr>';
			
		}	
	}
	
	
	
	/**
	 * Show calendar
	 * 
	 * @author	Liviu
	 * @since 	Apr 2, 2008
	 */
	public function showCalendar() { ?>

<style>
.calendar {
	border:			<?=$this->outsideBorderSize?> <?=$this->outsideBorderType?> <?=$this->outsideBorderColor?>;
	font-family:	Tahoma, Arial,Helvetica,sans-serif;
	font-size:		10px;
	font-weight:	normal;
	color:			#000000;
	text-align:		center;
}
</style>
		<!-- START: CALENDAR -->
		<table width="<?=$this->calendarWidth?>" cellpadding="7" cellspacing="0" class="calendar">
			
			<!-- start: nav -->
			<tr>
				<th> <a href="<?=SERVER_ROOT?>/common/controller.php?action=doChangeDailyCalendarExe&amp;year=<?=$this->year-1?>&amp;month=<?=$this->month?>&amp;day=<?=$this->day?>">&lsaquo;&lsaquo;</a> </th>
				<th> <a href="<?=SERVER_ROOT?>/common/controller.php?action=doChangeDailyCalendarExe&amp;year=<?=$this->year?>&amp;month=<?=$this->month-1?>&amp;day=<?=$this->day?>">&lsaquo;</a> </th>
				<th colspan="3"><?=$this->convertIntMonthToString($this->month) ." ". $this->year?></th>
				<th> <a href="<?=SERVER_ROOT?>/common/controller.php?action=doChangeDailyCalendarExe&amp;year=<?=$this->year?>&amp;month=<?=$this->month+1?>&amp;day=<?=$this->day?>">&rsaquo;</a> </th>
				<th> <a href="<?=SERVER_ROOT?>/common/controller.php?action=doChangeDailyCalendarExe&amp;year=<?=$this->year+1?>&amp;month=<?=$this->month?>&amp;day=<?=$this->day?>">&rsaquo;&rsaquo;</a> </th>
			</tr>
			<!-- end: nav -->
			
			<!-- start: days of week -->
			<tr>
				<?php
					$daysOfWeek = $this->daysOfWeek();
					foreach($daysOfWeek as $dayKey => $day) {
						?>
						<th class="calenday_dayofweek">
							<span><b><?=$day[''. $this->dayLenght .'']?></b></span>
						</th>
						<?
					} // foreach end
				?>
			</tr>
			<!-- end: days of weekd -->
			
			<!-- start: month days -->
				<?=$this->getUpperDays()?>
				<?=$this->getMiddleDays()?>
				<?=$this->getLowerDays()?>
			<!-- end: month days -->
			
			<!-- -->
			<tr>
				<td colspan="7"><a href="<?=SERVER_ROOT?>/common/controller.php?action=doChangeDailyCalendarExe&amp;year=<?=date('Y')?>&amp;month=<?=date('m')?>&amp;day=<?=date('j')?>">Go to current date</a>
				</td>
			</tr>
			<!-- -->
			
		</table>
		<!-- END: CALENDAR -->
		<?
	}
	
} // End class
?>